@@ -67,26 +67,14 @@ from disspy.core import (
     DisApi,
     DisFlags,
     JsonOutput,
-    Showflake
+    Snowflake
 )
 from disspy.embed import (
     DisEmbed,
     DisField,
     DisColor
 )
-from disspy.errors import (
-    UserNitroTypeError,
-    InternetError,
-    MissingPerms,
-    InvalidArgument,
-    BotEventTypeError,
-    BotStatusError,
-    ClassTypeError,
-    BotApplicationIdInvalid,
-    BotEventVisibleError,
-    ApplicationIdIsNone,
-    Unauthorized
-)
+
 from disspy.guild import DisGuild
 from disspy.logger import Logger
 from disspy.message import (
