@@ -21,17 +21,24 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
+
+from typing import (
+    Optional,
+    Union,
+    List
+)
+from json import dumps
+from aiohttp import ClientSession
+from requests import get
+from disspy.typ import Url
+
+
 from disspy.embed import DisEmbed
 from disspy.message import DisMessage
 from disspy.guild import DisGuild
 from disspy.jsongenerators import _EmbedGenerator
 from disspy.ui import ActionRow
 
-from typing import (
-    Optional,
-    Union
-)
-
 __all__: tuple = (
     "DisChannel",
     "DisDmChannel"
@@ -40,41 +47,78 @@ __all__: tuple = (
 
 class _SendingRestHandler:
     @staticmethod
-    async def execute(id, payload, token):
-        from aiohttp import ClientSession as CS
-        from json import dumps
+    async def execute(channel_id: int, payload: dict, token: str) -> dict:
+        """execute
+        Send messages in channels
 
-        async with CS(headers={'Authorization': f'Bot {token}', 'content-type': 'application/json'}) as s:
-            _u = f"https://discord.com/api/v9/channels/{id}/messages"
+        Args:
+            channel_id (int): Channel id
+            payload (dict): Dict json
+            token (str): Bot token
 
-            async with s.post(_u, data=dumps(payload)) as p:
-                j = await p.json()
+        Returns:
+            dict: Json output
+        """
+        async with ClientSession(headers={'Authorization': f'Bot {token}',
+                                          'content-type': 'application/json'}) as session:
+            _u = f"https://discord.com/api/v9/channels/{channel_id}/messages"
+
+            async with session.post(_u, data=dumps(payload)) as data:
+                j = await data.json()
 
                 return j
 
     @staticmethod
-    async def delete_channel(url, token):
-        from aiohttp import ClientSession
+    async def put_without_payload(url: Url, token):
+        """put_without_payload
+        PUT method wtthout payload
 
-        async with ClientSession(headers={'Authorization': f'Bot {token}', 'content-type': 'application/json'}) as s:
-            await s.delete(url=url)
+        Args:
+            url (Url): url for operation
+            token (str): Bot token
+        """
+        async with ClientSession(headers={'Authorization': f'Bot {token}',
+                                          'content-type': 'application/json'}) as session:
+            await session.put(url)
+
+    @staticmethod
+    async def delete(url: Url, token: str):
+        """delete
+        DELETE method
+
+        Args:
+            url (Url): url for operation
+            token (str): Bot token
+        """
+        async with ClientSession(headers={'Authorization': f'Bot {token}',
+                                          'content-type': 'application/json'}) as session:
+            await session.delete(url=url)
+
+    @staticmethod
+    async def post_without_payload(url: Url, token: str):
+        """post_without_payload
+        POST method wtthout payload
+
+        Args:
+            url (Url): url for operation
+            token (str): Bot token
+        """
+        async with ClientSession(headers={'Authorization': f'Bot {token}',
+                                          'content-type': 'application/json'}) as session:
+            await session.post(url=url)
 
 
 class _GettingChannelData:
     @staticmethod
-    def execute(id, token):
-        from requests import get
-
-        _u = f"https://discord.com/api/v9/channels/{id}"
+    def execute(channel_id, token):
+        _u = f"https://discord.com/api/v10/channels/{channel_id}"
         _h = {'Authorization': f'Bot {token}'}
 
         return get(_u, headers=_h).json()
 
     @staticmethod
-    def fetch(id, token, message_id):
-        from requests import get
-
-        _u = f"https://discord.com/api/v9/channels/{id}/messages/{message_id}"
+    def fetch(channel_id, token, message_id):
+        _u = f"https://discord.com/api/v10/channels/{channel_id}/messages/{message_id}"
         _h = {'Authorization': f'Bot {token}'}
 
         return get(_u, headers=_h).json()
@@ -85,7 +129,7 @@ class _GettingGuildData:
     def execute(id, token):
         from requests import get
 
-        _u = f"https://discord.com/api/v9/guilds/{id}"
+        _u = f"https://discord.com/api/v10/guilds/{id}"
         _h = {'Authorization': f'Bot {token}'}
 
         return get(_u, headers=_h).json()
@@ -121,16 +165,19 @@ class DisChannel:
         __eq__ have using in "==" operator
 
         :param other: Other object (DisChannel)
-        :return: bool -> if id of this object equals with id of other object :returns: True, else False:
+        :return: bool -> if id of this object equals with id of other object
+                         :returns: True, else False:
         """
         return self.id == other.id
 
-    async def send(self, content: Optional[str] = None, embeds: Optional[list[DisEmbed]] = None, action_row: Optional[ActionRow] = None) -> Union[DisMessage, None]:
+    async def send(self, content: Optional[str] = None, embeds: Optional[List[DisEmbed]] = None,
+                   action_row: Optional[ActionRow] = None) -> Union[DisMessage, None]:
         """
         Sending messages to discord channel
 
         :param content: str = None -> Content of message which will be sended (default is None)
-        :param embeds: list[DisEmbed] = None -> Embeds for message (DisEmbed - embed) (default is None)
+        :param embeds: List[DisEmbed] = None -> Embeds for message (DisEmbed - embed)
+                                                (default is None)
         :param action_row: ActionRow = None -> Action Row with components (default is None)
         :return DisMessage: Message which was sended
         """
@@ -179,10 +226,25 @@ class DisChannel:
 
         return DisMessage(d, self._t)
 
+    async def pin(self, message_id: int):
+        _u = f"https://discord.com/api/v10/channels/{self.id}/pins/{message_id}"
+
+        await _SendingRestHandler.put_without_payload(_u, self._t)
+
+    async def unpin(self, message_id: int):
+        _u = f"https://discord.com/api/v10/channels/{self.id}/pins/{message_id}"
+
+        await _SendingRestHandler.delete(_u, self._t)
+
     async def delete(self):
         _u = f"https://discord.com/api/v10/channels/{self.id}"
 
-        await _SendingRestHandler.delete_channel(_u, self._t)
+        await _SendingRestHandler.delete(_u, self._t)
+
+    async def typing(self):
+        _u = f"https://discord.com/api/v10/channels/{self.id}/typing"
+
+        await _SendingRestHandler.post_without_payload(_u, self._t)
 
 
 class DisDmChannel:
@@ -201,12 +263,14 @@ class DisDmChannel:
         self.id = _data["id"]
         self._t = token
 
-    async def send(self, content: Optional[str] = None, embeds: Optional[list[DisEmbed]] = None, action_row: Optional[ActionRow] = None) -> Union[DisMessage, None]:
+    async def send(self, content: Optional[str] = None, embeds: Optional[List[DisEmbed]] = None,
+                   action_row: Optional[ActionRow] = None) -> Union[DisMessage, None]:
         """
         Sending messages to discord channel
 
         :param content: str = None -> Content of message which will be sended (default is None)
-        :param embeds: list[DisEmbed] = None -> Embeds for message (DisEmbed - embed) (default is None)
+        :param embeds: List[DisEmbed] = None -> Embeds for message (DisEmbed - embed)
+                                                (default is None)
         :param action_row: ActionRow = None -> Action Row with components (default is None)
         :return DisMessage: Message which was sended
         """
