@@ -28,7 +28,6 @@ import asyncio
 from typing import (
     TypeVar,
     Union,
-    Optional,
     Awaitable,
     Callable,
     NewType,
@@ -41,10 +40,13 @@ from typing import (
     Generic,
     final
 )
+from datetime import datetime
+from time import mktime
 from aiohttp import ClientSession
 from requests import delete, post, get, patch
 import colorama
 
+
 # disspy imports
 from disspy.channel import DisChannel, DisDmChannel
 from disspy.errors import ClassTypeError
@@ -55,8 +57,9 @@ from disspy.message import (
     MessageDeleteEvent,
     DmMessageDeleteEvent
 )
+from disspy.reaction import DisEmoji, DisReaction, DisRemovedReaction
 from disspy.user import DisUser
-
+from disspy.application_commands import Context, _Argument, OptionArgs
 
 JsonOutput = NewType("JsonOutput", Dict[str, Any])
 
@@ -66,7 +69,7 @@ __all__: tuple = (
     "JsonOutput",
     "FlowOpcodes",
     "DisFlags",
-    "Showflake",
+    "Snowflake",
     "ChannelId",
     "UserId",
     "GuildlId",
@@ -181,6 +184,14 @@ class _DebugLoggingWebsocket:
         return _result
 
 
+class _DebugLoggingAwaiting:
+    def __new__(cls, gateway_event_name, event_name):
+        _result = f'{colorama.Fore.RED}Awaiting event "{gateway_event_name}": '
+        _result += f'{colorama.Fore.YELLOW}{event_name}(){colorama.Fore.RESET}'
+
+        return _result
+
+
 class _RequestsUserClass:
     """
     Class for Getting and Posting data in Discord
@@ -330,22 +341,22 @@ class DisFlags:
             14. DIRECT_MESSAGE_REACTIONS
             15. DIRECT_MESSAGE_TYPING
             16. GUILD_SCHEDULED_EVENTS
-            17. MESSAGE_CONTENT (Privilleged intent)
+            17. MESSAGE_CONTENT (Privileged intent)
 
         :return int: integer value of intents
         """
-        return 98303
+        return 3276799
 
 
 T = TypeVar("T", str, int)
 
 
 @final
-class Showflake(Generic[T]):
+class Snowflake(Generic[T]):
     """
     Class info
 
-    Showflake is using for simpled work with tokens and ids.
+    Snowflake is using for simpled work with tokens and ids.
 
     :var self.isid:
     """
@@ -394,7 +405,7 @@ class Rest:
 
         self.__slots__ = [self._headers]
 
-    def get(self, goal: str, goal_id: Union[int, Showflake]) -> JsonOutput:
+    def get(self, goal: str, goal_id: Union[int, Snowflake]) -> JsonOutput:
         """
         :param goal: guild/channel/user
         :param id: id of guild/channel/user
@@ -436,6 +447,16 @@ class Rest:
         return get(_url, self._headers).json()
 
     async def send_message(self, channel_id, json_post):
+        """send_message
+        Send messages in channels
+
+        Args:
+            channel_id (int): Channel id
+            json_post (dict): Json data for send
+
+        Returns:
+            dict: Json output
+        """
         _url = f"{_mainurl()}channels/{channel_id}/messages"
 
         async with ClientSession(headers=self._headers) as session:
@@ -474,64 +495,39 @@ class Flow:
         self._headers = {}
 
         self.ws = None
+        self.ons = None
 
     # Event methods
-    async def on_ready(self):
-        pass
+    async def on_channel(self, message: DisMessage):
+        """on_channel
+        "MESSAGE CREATE" event, but only in one channel
 
-    async def on_messagec(self, m: DisMessage):
-        pass
+        Args:
+            message (DisMessage): Message that was created
+        """
+        return message.content
 
-    async def on_messageu(self, m: DisMessage):
-        pass
+    async def register(self, data):
+        """register
+        Register user id
 
-    async def on_messaged(self, e: MessageDeleteEvent):
-        pass
-
-    async def on_dmessagec(self, m: DmMessage):
-        pass
-
-    async def on_dmessageu(self, m: DmMessage):
-        pass
-
-    async def on_dmessaged(self, e: DmMessageDeleteEvent):
-        pass
-
-    async def on_interaction(self, token, interaction_id, command_name: Text, bot_token: Showflake[str], interaction_type: int, data: JsonOutput, type_of_command: Optional[int] = None):
-        pass
-
-    async def on_components(self, d):
-        pass
-
-    async def on_modal_sumbit(self, d):
-        pass
-
-    async def on_register(self):
-        pass
-
-    async def register2(self):
-        pass
-
-    async def on_reaction(self, r):
-        pass
-
-    async def on_reactionr(self, r):
-        pass
-
-    async def on_typing_start(self, u: DisUser, channel: DisChannel):
-        pass
-
-    async def on_dm_typing_start(self, u: DisUser, channel: DisDmChannel):
-        pass
-
-    async def on_channel(self, m: DisMessage):
-        pass
-
-    async def register(self, d):
-        self.user_id = d["user"]["id"]
+        Args:
+            data (dict): Data of "READY" event
+        """
+        self.user_id = data["user"]["id"]
 
     # Sending/Getting
     async def send_request(self, data, ws):
+        """send_request
+        Send json request to Gateway
+
+        Args:
+            data (dict): Json data
+            ws (Any): Aiohttp websocket
+
+        Returns:
+            dict: Your json data
+        """
         await ws.send_json(data)
 
         if self._debug:
@@ -540,6 +536,15 @@ class Flow:
         return data
 
     async def get_responce(self, ws):
+        """get_responce
+        Get json output from Gateway
+
+        Args:
+            ws (Any): Aiohttp websocket
+
+        Returns:
+            dict: Json output
+        """
         try:
             j = await ws.receive_json()
         except TypeError:
@@ -558,43 +563,25 @@ class Flow:
 
     # Runners
     async def run(self, ons, status, debug, act):
+        """run
+        Run Flow (Gateway)
+
+        Args:
+            ons (dict): Dict with _type_: _func_ model for awaiting this events
+            status (str): Status of bot
+            debug (bool): Debug id enabled?
+            act (dict): Activity of bot
+        """
         self._debug = debug
         self.status = status
         self.activity = act
+        self.ons = ons
 
         # Registering events
-        if ons["ready"] is not None:
-            self.on_ready = ons["ready"]
-        if ons["messagec"] is not None:
-            self.on_messagec = ons["messagec"]
-        if ons["messageu"] is not None:
-            self.on_messageu = ons["messageu"]
-        if ons["messaged"] is not None:
-            self.on_messaged = ons["messaged"]
-        if ons["dmessagec"] is not None:
-            self.on_dmessagec = ons["dmessagec"]
-        if ons["dmessageu"] is not None:
-            self.on_dmessageu = ons["dmessageu"]
-        if ons["dmessaged"] is not None:
-            self.on_dmessaged = ons["dmessaged"]
-        if ons["reaction"] is not None:
-            self.on_reaction = ons["reaction"]
-        if ons["reactionr"] is not None:
-            self.on_reactionr = ons["reactionr"]
-        if ons["typing"] is not None:
-            self.on_typing_start = ons["typing"]
-        if ons["dm_typing"] is not None:
-            self.on_dm_typing_start = ons["dm_typing"]
         if ons["channel"][0] is not None:
             self.on_channel = ons["channel"][0]
             self.on_channel__id = ons["channel"][1]
 
-        self.on_interaction = ons["interaction"]
-        self.on_components = ons["components"]
-        self.on_modal_sumbit = ons["modalsumbit"]
-        self.on_register = ons["register"]
-        self.register2 = ons["register2"]
-
         # Other
         self.isrunning = True
         self.isafk = False
@@ -604,16 +591,15 @@ class Flow:
         await self._runner()
 
     async def _runner(self):
-        async with ClientSession() as s:
-            async with s.ws_connect(f"wss://gateway.discord.gg/?v={self.gateway_version}&encoding=json") as ws:
+        async with ClientSession() as session:
+            async with session.ws_connect(
+                f"wss://gateway.discord.gg/?v={self.gateway_version}&encoding=json") as ws:
                 self.ws = ws
 
                 j = await self.get_responce(ws)
 
                 interval = j["d"]["heartbeat_interval"]
 
-                from datetime import datetime
-                from time import mktime
 
                 await self.send_request({"op": 2, "d": {
                     "token": self.token,
@@ -631,13 +617,19 @@ class Flow:
                     }
                 }}, ws)
 
-                del mktime, datetime
-
                 self.isrunning = True
 
-                await asyncio.wait(fs=[self.heartbeat(ws, interval / 1000), self._events_checker(ws)])
+                await asyncio.wait(
+                    fs=[self.heartbeat(ws, interval / 1000), self._events_checker(ws)])
 
     async def heartbeat(self, ws, interval):
+        """heartbeat
+        Function with sending heartbeating to Gateway
+
+        Args:
+            ws (Any): Aiohttp websocket
+            interval (int): Heartbeat interval
+        """
         while True:
             await self.send_request({"op": 1, "d": None, "t": None}, ws)
 
@@ -648,148 +640,221 @@ class Flow:
             event_json = await self.get_responce(ws)
             event = _FlowEvent(event_json)
 
-            if event.type == "READY":
-                await self.register(event.data)
-                await self.register2()
-                await self.on_register()
+            try:
+                if event.type == "READY":
+                    await self.register(event.data)
 
-                await self.on_ready()
+                    if self._debug:
+                        print(_DebugLoggingAwaiting(event.type, "register"))
 
-            elif event.type == "MESSAGE_CREATE":
-                _u: str = f"https://discord.com/api/v10/channels/{event.data['channel_id']}"
+                    await self.ons["register2"]()
 
-                if not event.data["author"]["id"] == self.user_id:
-                    async with ClientSession(headers={'Authorization': f'Bot {self.token}', 'content-type': 'application/json'}) as s:
-                        async with s.get(_u) as g:
-                            j = await g.json()
+                    if self._debug:
+                        print(_DebugLoggingAwaiting(event.type, "on_register2"))
+
+                    await self.ons["register"]()
+
+                    if self._debug:
+                        print(_DebugLoggingAwaiting(event.type, "on_register"))
+
+                    await self.ons["ready"]()
+
+                    if self._debug:
+                        print(_DebugLoggingAwaiting(event.type, "on_ready"))
+
+                elif event.type == "MESSAGE_CREATE":
+                    _u: str = f"https://discord.com/api/v10/channels/{event.data['channel_id']}"
+
+                    if not event.data["author"]["id"] == self.user_id:
+                        async with ClientSession(
+                            headers={'Authorization': f'Bot {self.token}',
+                                     'content-type': 'application/json'}) as session:
+                            async with session.get(_u) as data:
+                                j = await data.json()
+
+                                if j["type"] == 0:
+                                    _m = DisMessage(event.data, self.token)
+
+                                    if int(event.data["channel_id"]) == int(self.on_channel__id):
+                                        await self.on_channel(_m)
+
+                                        if self._debug:
+                                            print(_DebugLoggingAwaiting(event.type, "on_channel"))
+
+
+                                    await self.ons["messagec"](_m)
+
+                                    if self._debug:
+                                        print(_DebugLoggingAwaiting(event.type, "on_messagec"))
+                                elif j["type"] == 1:
+                                    _m = DmMessage(event.data, self.token)
+
+                                    await self.ons["dmessagec"](_m)
+
+                                    if self._debug:
+                                        print(_DebugLoggingAwaiting(event.type, "on_dmessagec"))
+
+                elif event.type == "MESSAGE_UPDATE":
+                    _u: str = f"https://discord.com/api/v10/channels/{event.data['channel_id']}"
+
+                    if not event.data["author"]["id"] == self.user_id:
+                        async with ClientSession(
+                            headers={'Authorization': f'Bot {self.token}',
+                                     'content-type': 'application/json'}) as session:
+                            async with session.get(_u) as data:
+                                j = await data.json()
+
+                                if j["type"] == 0:
+                                    _m = DisMessage(event.data, self.token)
+
+                                    await self.ons["messageu"](_m)
+
+                                    if self._debug:
+                                        print(_DebugLoggingAwaiting(event.type, "on_messageu"))
+                                elif j["type"] == 1:
+                                    _m = DmMessage(event.data, self.token)
+
+                                    await self.ons["dmessageu"](_m)
+
+                                    if self._debug:
+                                        print(_DebugLoggingAwaiting(event.type, "on_dmessageu"))
+
+                elif event.type == "MESSAGE_DELETE":
+                    _u = f"https://discord.com/api/v10/channels/{event.data['channel_id']}"
+
+                    async with ClientSession(
+                        headers={'Authorization': f'Bot {self.token}',
+                                 'content-type': 'application/json'}) as session:
+                        async with session.get(_u) as data:
+                            j = await data.json()
 
                             if j["type"] == 0:
+                                _e = MessageDeleteEvent(event.data, self.token)
 
-                                _m = DisMessage(event.data, self.token)
+                                await self.ons["messaged"](_e)
 
-                                if int(event.data["channel_id"]) == int(self.on_channel__id):
-                                    await self.on_channel(_m)
-
-                                await self.on_messagec(_m)
+                                if self._debug:
+                                    print(_DebugLoggingAwaiting(event.type, "on_messaged"))
                             elif j["type"] == 1:
-                                _m = DmMessage(event.data, self.token)
+                                _e = DmMessageDeleteEvent(event.data, self.token)
 
-                                await self.on_dmessagec(_m)
+                                await self.ons["dmessaged"](_e)
 
-            elif event.type == "MESSAGE_UPDATE":
-                _u: str = f"https://discord.com/api/v10/channels/{event.data['channel_id']}"
+                                if self._debug:
+                                    print(_DebugLoggingAwaiting(event.type, "on_dmessaged"))
 
-                if not event.data["author"]["id"] == self.user_id:
-                    async with ClientSession(headers={'Authorization': f'Bot {self.token}', 'content-type': 'application/json'}) as s:
-                        async with s.get(_u) as g:
-                            j = await g.json()
+                elif event.type == "INTERACTION_CREATE":
+                    if event.data["type"] == 2:  # Application Commands
+                        await self.ons["interaction"](
+                            event.data["token"], event.data["id"], event.data["data"]["name"],
+                            self.token, event.data["type"], event.data, event.data["data"]["type"])
 
-                            if j["type"] == 0:
-                                _m = DisMessage(event.data, self.token)
+                        if self._debug:
+                            print(_DebugLoggingAwaiting(event.type, "on_interaction"))
+                    if event.data["type"] == 3 or event.data["type"] == 4:  # Components
+                        await self.ons["components"](event.data)
 
-                                await self.on_messageu(_m)
-                            elif j["type"] == 1:
-                                _m = DmMessage(event.data, self.token)
+                        if self._debug:
+                            print(_DebugLoggingAwaiting(event.type, "on_components"))
 
-                                await self.on_dmessageu(_m)
+                    if event.data["type"] == 5:  # Modal Sumbit
+                        await self.ons["modalsumbit"](event.data)
 
-            elif event.type == "MESSAGE_DELETE":
-                _u = f"https://discord.com/api/v10/channels/{event.data['channel_id']}"
+                        if self._debug:
+                            print(_DebugLoggingAwaiting(event.type, "on_modalsumbit"))
 
-                async with ClientSession(headers={'Authorization': f'Bot {self.token}', 'content-type': 'application/json'}) as s:
-                    async with s.get(_u) as g:
-                        j = await g.json()
+                elif event.type == "MESSAGE_REACTION_ADD":
+                    _u = DisUser(event.data["member"]["user"], self.token)
+                    _m_id = int(event.data["message_id"])
+                    _c_id = int(event.data["channel_id"])
+                    _g_id = int(event.data["guild_id"])
 
-                        if j["type"] == 0:
-                            _e = MessageDeleteEvent(event.data, self.token)
+                    _e_json = event.data["emoji"]
 
-                            await self.on_messaged(_e)
-                        elif j["type"] == 1:
-                            _e = DmMessageDeleteEvent(event.data, self.token)
-
-                            await self.on_dmessaged(_e)
-
-            elif event.type == "INTERACTION_CREATE":
-                if event.data["type"] == 2:  # Application Commands
-                    await self.on_interaction(event.data["token"], event.data["id"], event.data["data"]["name"],
-                                              self.token, event.data["type"], event.data, event.data["data"]["type"])
-                if event.data["type"] == 3 or event.data["type"] == 4:  # Components
-                    await self.on_components(event.data)
-
-                if event.data["type"] == 5:  # Modal Sumbit
-                    await self.on_modal_sumbit(event.data)
-
-            elif event.type == "MESSAGE_REACTION_ADD":
-                from disspy.reaction import DisEmoji, DisReaction
-                _u = DisUser(event.data["member"]["user"], self.token)
-                _m_id = int(event.data["message_id"])
-                _c_id = int(event.data["channel_id"])
-                _g_id = int(event.data["guild_id"])
-
-                _e_json = event.data["emoji"]
-
-                if _e_json["id"] is None:
-                    _e = DisEmoji(unicode=_e_json["name"])
-                else:
-                    _e = DisEmoji(name=_e_json["name"], emoji_id=int(_e_json["id"]))
-
-                _r = DisReaction(_u, _m_id, _c_id, _g_id, _e, self.token)
-
-                await self.on_reaction(_r)
-
-            elif event.type == "MESSAGE_REACTION_REMOVE":
-                from disspy.reaction import DisEmoji, DisRemovedReaction
-                _m_id = int(event.data["message_id"])
-                _c_id = int(event.data["channel_id"])
-                _g_id = int(event.data["guild_id"])
-
-                _e_json = event.data["emoji"]
-
-                if _e_json["id"] is None:
-                    _e = DisEmoji(unicode=_e_json["name"])
-                else:
-                    _e = DisEmoji(name=_e_json["name"], emoji_id=int(_e_json["id"]))
-
-                _r = DisRemovedReaction(_m_id, _c_id, _g_id, _e, self.token)
-
-                await self.on_reactionr(_r)
-
-            elif event.type == "TYPING_START":
-                try:
-                    if event.data["guild_id"]:
-                        _u: DisUser = DisUser(event.data["member"]["user"], self.token)
-                        _c: DisChannel = DisChannel(event.data["channel_id"], self.token)
-
-                        await self.on_typing_start(_u, _c)
+                    if _e_json["id"] is None:
+                        _e = DisEmoji(unicode=_e_json["name"])
                     else:
+                        _e = DisEmoji(name=_e_json["name"], emoji_id=int(_e_json["id"]))
+
+                    _r = DisReaction(_u, _m_id, _c_id, _g_id, _e, self.token)
+
+                    await self.ons["reaction"](_r)
+
+                    if self._debug:
+                        print(_DebugLoggingAwaiting(event.type, "on_reaction"))
+
+                elif event.type == "MESSAGE_REACTION_REMOVE":
+                    _m_id = int(event.data["message_id"])
+                    _c_id = int(event.data["channel_id"])
+                    _g_id = int(event.data["guild_id"])
+
+                    _e_json = event.data["emoji"]
+
+                    if _e_json["id"] is None:
+                        _e = DisEmoji(unicode=_e_json["name"])
+                    else:
+                        _e = DisEmoji(name=_e_json["name"], emoji_id=int(_e_json["id"]))
+
+                    _r = DisRemovedReaction(_m_id, _c_id, _g_id, _e, self.token)
+
+                    await self.ons["reactionr"](_r)
+
+                    if self._debug:
+                        print(_DebugLoggingAwaiting(event.type, "on_reactionr"))
+
+                elif event.type == "TYPING_START":
+                    try:
+                        if event.data["guild_id"]:
+                            _u: DisUser = DisUser(event.data["member"]["user"], self.token)
+                            _c: DisChannel = DisChannel(event.data["channel_id"], self.token)
+
+                            await self.ons["typing"](_u, _c)
+
+                            if self._debug:
+                                print(_DebugLoggingAwaiting(event.type, "on_typing"))
+                        else:
+                            _u_id = event.data["user_id"]
+                            _u_json = Rest(self.token).get("user", _u_id)
+
+                            _u: DisUser = DisUser(_u_json, self.token)
+                            _c: DisDmChannel = DisDmChannel(event.data["channel_id"], self.token)
+
+                            await self.ons["dm_typing"](_u, _c)
+
+                            if self._debug:
+                                print(_DebugLoggingAwaiting(event.type, "on_dm_typing"))
+                    except KeyError:
                         _u_id = event.data["user_id"]
                         _u_json = Rest(self.token).get("user", _u_id)
 
                         _u: DisUser = DisUser(_u_json, self.token)
                         _c: DisDmChannel = DisDmChannel(event.data["channel_id"], self.token)
 
-                        await self.on_dm_typing_start(_u, _c)
-                except KeyError:
-                    _u_id = event.data["user_id"]
-                    _u_json = Rest(self.token).get("user", _u_id)
+                        await self.ons["dm_typing"](_u, _c)
 
-                    _u: DisUser = DisUser(_u_json, self.token)
-                    _c: DisDmChannel = DisDmChannel(event.data["channel_id"], self.token)
-
-                    await self.on_dm_typing_start(_u, _c)
+                        if self._debug:
+                            print(_DebugLoggingAwaiting(event.type, "on_dm_typing"))
+            except TypeError:
+                pass
 
             await asyncio.sleep(0.5)
 
     async def disconnecter(self):
+        """disconnecter
+        Disconnect from Gateway
+        """
         await self.ws.close()
 
 
 @final
 class DisApi(_RequestsUserClass):
+    """DisApi
+    Class for init Rest and Flow event and edit they
+    """
     def __init__(self, token: str, intents, application_id):
         """
         Init Class
-        -----
+
         :param token: Token of bot (from Discord Developer Portal)
         :param intents: Intents of bot
         :param application_id: Application id of bot (from Discord Developer Portal)
@@ -805,12 +870,12 @@ class DisApi(_RequestsUserClass):
         self.token = token
         self.application_id = application_id
 
-        self.f = Flow(10, self.token, intents)
+        self.flow = Flow(10, self.token, intents)
         self._r = Rest(self.token)
 
         self.app_commands = []
         self.raw_app_commands = []
-        
+
         self.user = None
 
         self.app_commands.append({})  # Slash Commands
@@ -818,13 +883,24 @@ class DisApi(_RequestsUserClass):
         self.app_commands.append({})  # Message Commands
 
     def fetch(self, channel_id, message_id) -> DisMessage:
+        """fetch
+        Fetch message by its id and channel id
+
+        Args:
+            channel_id (int): Channel id
+            message_id (int): Message id
+
+        Returns:
+            DisMessage: Fetched message
+        """
         _url = f"{_mainurl()}channels/{channel_id}/messages/{message_id}"
 
         _d = self._r.fetch(channel_id, message_id)
 
         return DisMessage(_d, self.token)
 
-    async def run(self, status, ons: Dict[Text, Callable], debug: bool, act: Dict[str, Any]) -> NoReturn:
+    async def run(self, status, ons: Dict[Text, Callable], debug: bool,
+                  act: Dict[str, Any]) -> NoReturn:
         """
         Run the flow of DisApi or run the bot.
         Running bot in Discord, changing status and registering
@@ -845,10 +921,10 @@ class DisApi(_RequestsUserClass):
 
         _raws = get(_url, headers=self._headers).json()
 
-        for r in _raws:
+        for raw in _raws:
             for j in self.app_commands_jsons:
-                if r["name"] == j["name"] and r["type"] == j["type"]:
-                    _res = r
+                if raw["name"] == j["name"] and raw["type"] == j["type"]:
+                    _res = raw
 
                     try:
                         _res["description"] = j["description"]
@@ -860,40 +936,31 @@ class DisApi(_RequestsUserClass):
                     except KeyError:
                         pass
 
-                    patch(f"{_url}/{r['id']}", json=j, headers=self._headers)
+                    patch(f"{_url}/{raw['id']}", json=j, headers=self._headers)
                 else:
-                    delete(f"{_url}/{r['id']}", headers=self._headers)
+                    delete(f"{_url}/{raw['id']}", headers=self._headers)
                     post(url=_url, json=j, headers=self._headers)
 
-        await self.f.run(ons, status, debug, act)
-
-    async def disconnecter(self):
-        await self.f.disconnecter()
-
-    async def _on_messagec(self, message):
-        pass
-
-    async def _on_ready(self):
-        pass
+        await self.flow.run(ons, status, debug, act)
 
     async def _register2(self):
         # pass
-        self.user: DisUser = self.get_user(self.f.user_id)
+        self.user: DisUser = self.get_user(self.flow.user_id)
 
-    async def _on_interaction(self, token, interaction_id, command_name, bot_token: str, interaction_type, data: JsonOutput, type_of_command: int = None):
+    async def _on_interaction(self, token, interaction_id, command_name, bot_token: str,
+                              interaction_type, data: JsonOutput, type_of_command=None) -> NoReturn:
         if type_of_command is None:
-            return  # Not components!
+            return
         else:
             if interaction_type == 2:
-                from disspy.application_commands import Context
                 _ctx = Context(token, interaction_id, bot_token)
 
                 try:
                     if type_of_command == 3:  # Message Commands
-                        rs: dict = data["data"]["resolved"]["messages"]
+                        resolved: dict = data["data"]["resolved"]["messages"]
 
-                        _m_id = list(rs.keys())[0]
-                        _m_d: dict = rs[_m_id]
+                        _m_id = list(resolved.keys())[0]
+                        _m_d: dict = resolved[_m_id]
 
                         try:
                             _m_d["id"] = _m_id
@@ -905,10 +972,10 @@ class DisApi(_RequestsUserClass):
                         await self.app_commands[type_of_command - 1][command_name](_ctx, _m)
 
                     elif type_of_command == 2:  # User Commands
-                        rs: dict = data["data"]["resolved"]["users"]
+                        resolved: dict = data["data"]["resolved"]["users"]
 
-                        _u_id = list(rs.keys())[0]
-                        _u_d: dict = rs[_u_id]
+                        _u_id = list(resolved.keys())[0]
+                        _u_d: dict = resolved[_u_id]
 
                         try:
                             _u_d["id"] = _u_id
@@ -922,44 +989,42 @@ class DisApi(_RequestsUserClass):
                     elif type_of_command == 1:  # Slash Commands
                         _args = []
 
-                        from disspy.application_commands import _Argument, OptionArgs
-
                         try:
-                            for o in data["data"]["options"]:
-                                _args.append(_Argument(o["name"],
-                                                       o["type"],
-                                                       o["value"]))
+                            for option in data["data"]["options"]:
+                                _args.append(_Argument(option["name"],
+                                                       option["type"],
+                                                       option["value"]))
                         except KeyError:
                             _args = []
 
-                        await self.app_commands[type_of_command - 1][command_name](_ctx, OptionArgs(_args))
+                        func = self.app_commands[type_of_command - 1][command_name]
+
+                        await func(_ctx, OptionArgs(_args))
                     else:
                         pass
                 except KeyError:
-                    print("What! Application command is invalid")
+                    pass
 
-    async def _on_components(self, d):
-        if d["data"]["component_type"] == 2:
-            from disspy.application_commands import Context
-            _ctx = Context(d["token"], d["id"], self.token)
-            await self.comsevs[d["data"]["custom_id"]](_ctx)
-        if d["data"]["component_type"] == 3:
-            from disspy.application_commands import Context
-            _ctx = Context(d["token"], d["id"], self.token)
-            _vs = d["data"]["values"]
-            await self.comsevs[d["data"]["custom_id"]](_ctx, _vs)
+    async def _on_components(self, data):
+        if data["data"]["component_type"] == 2:
+            _ctx = Context(data["token"], data["id"], self.token)
+            await self.comsevs[data["data"]["custom_id"]](_ctx)
 
-    async def _on_modal_sumbit(self, d):
-        from disspy.application_commands import Context
-        _ctx = Context(d["token"], d["id"], self.token)
-        coms = d["data"]["components"][0]["components"]
+        if data["data"]["component_type"] == 3:
+            _ctx = Context(data["token"], data["id"], self.token)
+            _vs = data["data"]["values"]
+            await self.comsevs[data["data"]["custom_id"]](_ctx, _vs)
+
+    async def _on_modal_sumbit(self, data):
+        _ctx = Context(data["token"], data["id"], self.token)
+        coms = data["data"]["components"][0]["components"]
         _v = ""
 
         for i in coms:
-            if i["custom_id"] == d["data"]["custom_id"]:
+            if i["custom_id"] == data["data"]["custom_id"]:
                 _v = i["value"]
 
-        await self.comsevs[d["data"]["custom_id"]](_ctx, _v)
+        await self.comsevs[data["data"]["custom_id"]](_ctx, _v)
 
     def get_user(self, user_id: UserId) -> DisUser:
         """
@@ -978,7 +1043,7 @@ class DisApi(_RequestsUserClass):
         :param user_id: id of user
         :return JsonOutput:
         """
-        user_id = int(user_id)  # If Showflake this will be int
+        user_id = int(user_id)  # If Snowflake this will be int
 
         return self._r.get("user", user_id)
 
@@ -989,7 +1054,7 @@ class DisApi(_RequestsUserClass):
         :param channel_id: id of channel
         :return DisChannel:
         """
-        channel_id = int(channel_id)  # If Showflake this will be int
+        channel_id = int(channel_id)  # If Snowflake this will be int
 
         return DisChannel(channel_id, self)
 
@@ -1000,7 +1065,7 @@ class DisApi(_RequestsUserClass):
         :param channel_id: id of channel
         :return JsonOutput:
         """
-        channel_id = int(channel_id)  # If Showflake this will be int
+        channel_id = int(channel_id)  # If Snowflake this will be int
 
         return self._r.get("channel", channel_id)
 
@@ -1011,7 +1076,7 @@ class DisApi(_RequestsUserClass):
         :param guild_id: id of guild
         :return DisGuild:
         """
-        guild_id = int(guild_id)  # If Showflake this will be int
+        guild_id = int(guild_id)  # If Snowflake this will be int
 
         return DisGuild(guild_id, self)
 
@@ -1023,11 +1088,18 @@ class DisApi(_RequestsUserClass):
         :return JsonOutput:
         """
 
-        guild_id = int(guild_id)  # If Showflake this will be int
+        guild_id = int(guild_id)  # If Snowflake this will be int
 
         return self._r.get("guild", guild_id)
 
-    def create_command(self, payload, func: Awaitable):
+    def create_command(self, payload: dict, func: Awaitable):
+        """create_command
+        Create application command
+
+        Args:
+            payload (dict): Json data of command
+            func (Awaitable): Function for awaiting command
+        """
         _url = f"https://discord.com/api/v10/applications/{self.application_id}/commands"
 
         def app_func_register(number):
@@ -1071,4 +1143,4 @@ class DisApi(_RequestsUserClass):
         Args:
             data (dict): Json data for sending request
         """
-        await self.f.send_request(data, self.f.ws)
+        await self.flow.send_request(data, self.flow.ws)
