@@ -22,18 +22,13 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-"""
-This file was created for manage Embeds in discord and using embeds in send messages feature
-
-Examples:
-    bot = disspy.DisBot('TOKEN')
-    disspy.DisChannel("ID").send(embed=disspy.DisEmbed(title='Testing'))
-"""
-
 # Imports
 from random import random
 from math import floor
-import typing
+from typing import (
+    NoReturn,
+    List
+)
 
 __all__: tuple = (
     "DisColor",
@@ -42,106 +37,92 @@ __all__: tuple = (
 )
 
 
-class _DocObject:
-    __description__: str = ""  # Description to class
-    __doc__: str = ""  # Mini doc with using
-    __varibles__: dict[str, str] = {}  # Description to varibles
-    __slots__: list[str] = []  # Slots with varibles names
+class DisColor:
+    """DisColor
+    Colors for embeds
+    """
 
-    _T: typing.TypeVar = None
+    __classname__ = "DisColor"
 
-    def __str__(self) -> str:  # Using in str()
-        r = ""
+    DEFAULT = 0
+    AQUA = 1752220
+    DARK_AQUA = 1146986
+    GREEN = 3066993
+    DARK_GREEN = 2067276
+    BLUE = 3447003
+    DARK_BLUE = 2123412
+    PURPLE = 10181046
+    DARK_PURPLE = 7419530
+    LUMINOUS_VIVID_PINK = 15277667
+    DARK_VIVID_PINK = 11342935
+    GOLD = 15844367
+    DARK_GOLD = 12745742
+    ORANGE = 15105570
+    DARK_ORANGE = 11027200
+    RED = 15158332
+    DARK_RED = 10038562
+    GREY = 9807270
+    DARK_GREY = 9936031
+    DARKER_GREY = 8359053
+    LIGHT_GREY = 12370112
+    NAVY = 3426654
+    DARK_NAVY = 2899536
+    YELLOW = 16776960
+    WHITE = 16777215
+    BLURPLE = 5793266
+    GREYPLE = 10070709
+    DARK_BUT_NOT_BLACK = 2895667
+    NOT_QUITE_BLACK = 2303786
+    OFFICIAL_GREEN = 5763719
+    OFFICIAL_YELLOW = 16705372
+    FUSCHIA = 15418782
+    BLACK = 2303786
+    OFFICIAL_RED = 15548997
 
-        for i in self.__varibles__.keys():
-            if r == "":
-                r += i
-            else:
-                r += f", {i}"
+    @staticmethod
+    def random():
+        """RANDOM
+        Generate random color
 
-        return r
-
-
-class DisColor(_DocObject):
-    _T = typing.TypeVar("DisColor")
-    __description__ = "Colors for embeds"
-
-    def __init__(self):
-        self.DEFAULT = 0
-        self.AQUA = 1752220
-        self.DARK_AQUA = 1146986
-        self.GREEN = 3066993
-        self.DARK_GREEN = 2067276
-        self.BLUE = 3447003
-        self.DARK_BLUE = 2123412
-        self.PURPLE = 10181046
-        self.DARK_PURPLE = 7419530
-        self.LUMINOUS_VIVID_PINK = 15277667
-        self.DARK_VIVID_PINK = 11342935
-        self.GOLD = 15844367
-        self.DARK_GOLD = 12745742
-        self.ORANGE = 15105570
-        self.DARK_ORANGE = 11027200
-        self.RED = 15158332
-        self.DARK_RED = 10038562
-        self.GREY = 9807270
-        self.DARK_GREY = 9936031
-        self.DARKER_GREY = 8359053
-        self.LIGHT_GREY = 12370112
-        self.NAVY = 3426654
-        self.DARK_NAVY = 2899536
-        self.YELLOW = 16776960
-        self.WHITE = 16777215
-        self.BLURPLE = 5793266
-        self.GREYPLE = 10070709
-        self.DARK_BUT_NOT_BLACK = 2895667
-        self.NOT_QUITE_BLACK = 2303786
-        self.OFFICIAL_GREEN = 5763719
-        self.OFFICIAL_YELLOW = 16705372
-        self.FUSCHIA = 15418782
-        self.OFFICIAL_RED = 15548997
-        self.BLACK = 2303786
-
-    @property
-    def RANDOM(self):
+        Returns:
+            int: Random color
+        """
         return floor(random() * 16777214) + 1
 
 
 class DisField:
+    """DisField
+    Fields for embeds
+    """
     def __init__(self, name: str, value: str, inline: bool = True):
         self.name = name
         self.value = value
         self.inline = inline
 
 
-class _EMBED:
-    title: str = ""
-    description: str = ""
-    color: str = ""
-    footer: str = ""
-
-    fields: list[DisField] = []
-
-
-class DisEmbed(_EMBED):
+class DisEmbed:
+    """DisEmbed
+    Embeds for messages
+    """
     def __init__(self, title: str, description: str = None, color=0xffffff, footer: str = None):
         self.title: str = title
         self.description: str = description
         self.color: str = color
         self.footer: str = footer
-        self.author = None
-        self.image = None
-        self.thumbnail = None
+        self.author: dict = None
+        self.image: dict = None
+        self.thumbnail: dict = None
 
-        self.fields: list[DisField] = []
+        self.fields: List[DisField] = []
 
-    def add_field(self, title: str, value: str):
+    def add_field(self, title: str, value: str) -> NoReturn:
         self.fields.append(DisField(title, value))
 
-    def add_field(self, field: DisField):
+    def add_field_from_obj(self, field: DisField) -> NoReturn:
         self.fields.append(field)
 
-    def set_author(self, name: str, url: str = None, icon_url: str = None, proxy_icon_url: str = None):
+    def set_author(self, name: str, url: str = None, icon_url: str = None,
+                   proxy_icon_url: str = None) -> NoReturn:
         """
         Set author for embed
         """
